==> cms-db_v0.9.tar.gz: admin/sort2.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

include('checkuser.inc.php');
checkuser('pages');
include('locale.inc.php');
$locale = new LocalizingClass('pages');

include('../functions_url.inc.php');
if ($_GET['sec'] == 'root') {
	$sec = '../data/pages/';
} else {
	$shorturl = get_filename_from_url($_GET['sec']);
	if ($shorturl === false) {
		die('Error: The page couldn\'t be found in the URL index.');
	}
	$sec = '../data/pages'.substr($shorturl, 0, strrpos($shorturl, '/'));
}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('title_sort') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
</head>
<body>

<h1><?php locale('title_sort') ?></h1>
<p>
<?php
$files = array();
$handle = opendir($sec);
while (false !== ($file = readdir($handle))) {
	if($file != '.' && $file != '..' && $file !='01,Home') {
		$files[] = $file;
	}
}
usort($files, 'strnatcmp');

if ($_GET['type'] == 'manual') {
	$array = $_GET['data'];
} if ($_GET['type'] == 'alpha') {
	$array = array();
	$i = 0;
	foreach ($files as $file) {
		$array[substr($file, 3)] = $i;
		$i++;
	}
	uksort($array, 'strnatcmp');
}
if (count($array) == count($files)) {
	$count = 01;
	foreach ($array as $i) {
		$count++;
		if ($count < 10) {
			$newcount = '0'.$count;
		} else {
			$newcount = $count;
		}
		$file = $files[$i];
		$new = $newcount.','.substr($file,3);
		rename($sec.'/'.$file, $sec.'/'.$new);
		locale('desc_sort-renamed');
		echo ' <i>'.$file.'</i> => <i>'.$new.'</i><br />';
	}
	include('cache.inc.php');
	clear_cache('pages');
	include('urlindex.inc.php');
	generate_urlindex();
	locale('desc_sort-urlindex');
} else {
	locale('desc_sort-error');
}
?>
</p>
<p>
	<a href="pages.php?<?php echo SID; csrf_protection_get_html() ?>#sort" class="nonewtab"><?php locale('desc_pages') ?></a>
</p>

</body>
</html>

==> cms-db_v0.9.3.tar.gz: admin/sort2.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

require_once('path.inc.php');
require_once(CDB_PATH_ADMIN.'/checkphp.inc.php');
require_once(CDB_PATH_ADMIN.'/checkuser.inc.php');

checkuser('pages');
require_once(CDB_PATH_ADMIN.'/locale.inc.php');
$locale = new LocalizingClass('pages');

include('../functions_url.inc.php');
if ($_GET['sec'] == 'root') {
	$sec = '../data/pages/';
} else {
	$shorturl = get_filename_from_url($_GET['sec']);
	if ($shorturl === false) {
		die('Error: The page couldn\'t be found in the URL index.');
	}
	$sec = '../data/pages'.substr($shorturl, 0, strrpos($shorturl, '/'));
}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('title_sort') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
</head>
<body>

<h1><?php locale('title_sort') ?></h1>
<p>
<?php
$files = array();
$handle = opendir($sec);
while (false !== ($file = readdir($handle))) {
	if($file != '.' && $file != '..' && $file !='01,Home') {
		$files[] = $file;
	}
}
usort($files, 'strnatcmp');

if ($_GET['type'] == 'manual') {
	$array = $_GET['data'];
} if ($_GET['type'] == 'alpha') {
	$array = array();
	$i = 0;
	foreach ($files as $file) {
		$array[substr($file, 3)] = $i;
		$i++;
	}
	uksort($array, 'strnatcmp');
}
if (count($array) == count($files)) {
	$count = 01;
	foreach ($array as $i) {
		$count++;
		if ($count < 10) {
			$newcount = '0'.$count;
		} else {
			$newcount = $count;
		}
		$file = $files[$i];
		$new = $newcount.','.substr($file,3);
		rename($sec.'/'.$file, $sec.'/'.$new);
		locale('desc_sort-renamed');
		echo ' <i>'.$file.'</i> => <i>'.$new.'</i><br />';
	}
	include('cache.inc.php');
	clear_cache('pages');
	include('urlindex.inc.php');
	generate_urlindex();
	locale('desc_sort-urlindex');
} else {
	locale('desc_sort-error');
}
?>
</p>
<p>
	<a href="pages.php?<?php echo SID; csrf_protection_get_html() ?>#sort" class="nonewtab"><?php locale('desc_pages') ?></a>
</p>

</body>
</html>
